==> AxolotlClient-3.1.6%2B1.20.1-sources.jar: io/github/axolotlclient/api/SimpleTextInputScreen.java <==
/*
 * Copyright © 2024 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.api;

import java.util.function.Consumer;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_342;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;

public class SimpleTextInputScreen extends class_437 {

	private final class_437 parent;
	private final class_2561 inputLabel;
	private final Consumer<String> consumer;
	private class_342 input;

	public SimpleTextInputScreen(class_437 parent, class_2561 title, class_2561 inputLabel, Consumer<String> consumer) {
		super(title);
		this.parent = parent;
		this.inputLabel = inputLabel;
		this.consumer = consumer;
	}

	@Override
	public void method_25426() {
		method_37063(input = new class_342(field_22793, field_22789 / 2 - 100, field_22790 / 2 - 10, 200, 20, inputLabel));

		method_37063(new class_4185.class_7840(class_5244.field_24335, button -> field_22787.method_1507(parent))
			.method_46434(field_22789 / 2 - 155, field_22790 - 50, 150, 20).method_46431());
		var done = method_37063(new class_4185.class_7840(class_5244.field_24334, button -> {
			if (!input.method_1882().isBlank()) {
				consumer.accept(input.method_1882());
			}
			field_22787.method_1507(parent);
		}).method_46434(field_22789 / 2 + 5, field_22790 - 50, 150, 20).method_46431());
		input.method_1863(s -> {
			done.field_22763 = !s.isBlank();
		});
		done.field_22763 = false;
	}

	@Override
	public void method_25393() {
		input.method_1865();
	}

	@Override
	public void method_25394(class_332 graphics, int i, int j, float f) {
		method_25420(graphics);
		super.method_25394(graphics, i, j, f);
		graphics.method_27535(field_22787.field_1772, inputLabel, (int) (field_22789 / 2F - 100), (int) (field_22790 / 2f - 20), -1);
		graphics.method_27534(this.field_22793, this.field_22785, this.field_22789 / 2, 20, 16777215);
	}
}

==> AxolotlClient-3.1.7%2B1.21.11-sources.jar: io/github/axolotlclient/api/SimpleTextInputScreen.java <==
/*
 * Copyright © 2024 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.api;

import java.util.function.Consumer;
import net.minecraft.class_2561;
import net.minecraft.class_332;
import net.minecraft.class_342;
import net.minecraft.class_4185;
import net.minecraft.class_437;
import net.minecraft.class_5244;

public class SimpleTextInputScreen extends class_437 {

	private final class_437 parent;
	private final class_2561 inputLabel;
	private final Consumer<String> consumer;
	private class_342 input;

	public SimpleTextInputScreen(class_437 parent, class_2561 title, class_2561 inputLabel, Consumer<String> consumer) {
		super(title);
		this.parent = parent;
		this.inputLabel = inputLabel;
		this.consumer = consumer;
	}

	@Override
	public void method_25426() {
		method_37063(input = new class_342(field_22793, field_22789 / 2 - 100, field_22790 / 2 - 10, 200, 20, inputLabel));

		method_37063(class_4185.method_46430(class_5244.field_24335, button -> field_22787.method_1507(parent))
			.method_46434(field_22789 / 2 - 155, field_22790 - 50, 150, 20).method_46431());
		var done = method_37063(class_4185.method_46430(class_5244.field_24334, button -> {
			if (!input.method_1882().isBlank()) {
				consumer.accept(input.method_1882());
			}
			field_22787.method_1507(parent);
		}).method_46434(field_22789 / 2 + 5, field_22790 - 50, 150, 20).method_46431());
		input.method_1863(s -> done.field_22763 = !s.isBlank());
		done.field_22763 = false;
	}

	@Override
	public void method_25394(class_332 graphics, int i, int j, float f) {
		super.method_25394(graphics, i, j, f);
		graphics.method_27535(field_22793, inputLabel, (int) (field_22789 / 2F - 100), (int) (field_22790 / 2f - 20), -1);
		graphics.method_27534(field_22793, this.field_22785, this.field_22789 / 2, 20, -1);
	}
}
